# Qt webkit git repository
# https://gitorious.org/+qt-developers/qt/webkit

Name:           qtwebkit
Summary:        Qt WebKit bindings
Group:          Development/KDE and Qt
Version:        2.3.4
Release:        %mkrel 9
License:        LGPLv2 with exceptions or GPLv3 with exceptions
URL:            http://trac.webkit.org/wiki/QtWebKit
Source0:        http://download.kde.org/stable/%{name}-2.3/%{version}/src/%{name}-%{version}.tar.gz

# patch from Linux From Scratch, fix build with bison 3.0
Patch2:		qt-5.1.0-bison_fixes-1.patch

# smaller debuginfo s/-g/-g1/ (debian uses -gstabs) to avoid 4gb size limit
Patch3:	        qtwebkit-2.3-debuginfo.patch

# tweak linker flags to minimize memory usage on "small" platforms
Patch4:         qtwebkit-2.3-save_memory.patch

# backport from qt5-qtwebkit: URLs visited during private browsing show up in WebpageIcons.db
Patch101:	webkit-qtwebkit-23-private_browsing.patch
# backport from qt5-qtwebkit: Fix g++ 5.0 build (QTBUG-44829)
Patch102:	qtwebkit-g++-5.0-build.patch

## upstream patches


BuildRequires:  bison
BuildRequires:  chrpath
BuildRequires:  flex
BuildRequires:  gperf
BuildRequires:  icu-devel
BuildRequires:  jpeg-devel
BuildRequires:  glib2-devel
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-app-1.0)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(libxslt)
BuildRequires:  pkgconfig(QtCore)  < 5.0.0
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xrender)
BuildRequires:  perl(version)
BuildRequires:  perl(Digest::MD5)
BuildRequires:  pkgconfig(QtLocation) >= 1.2
BuildRequires:  pkgconfig(QtSensors) >= 1.2
BuildRequires:  ruby


%description
Qt WebKit library is an open source web browser engine.

#------------------------------------------------------------------------------

%define major 4
%define api 2.2
%define libname %mklibname %{name} %{api} %{major}
%define oldwebkit %mklibname qtwebkit 4

%package -n     %{libname}
Summary:        Qt Webkit 2.3 Library
Group:          System/Libraries
# Needed for Google Music's music manager
# See: https://bugs.mageia.org/show_bug.cgi?id=7943
Provides:       qtwebkit
Requires:       qtwebkit-qmlplugin
Obsoletes:      %{oldwebkit} < 4:4.7.4-6

%description -n %{libname}

This package provides the runtime library for %{name}.

%files -n %{libname}
%{_qt4_libdir}/libQtWebKit.so.%{major}*

#------------------------------------------------------------------------------

%package -n qtwebkit-qmlplugin
Summary: QML plugin for QtWebKit
Group: System/Libraries
Conflicts:  %{libname} < 2.2.0-1

%description -n qtwebkit-qmlplugin

This package provides the qml plugin for QtWebKit.

%files -n qtwebkit-qmlplugin
%{_qt4_importdir}/QtWebKit/

#------------------------------------------------------------------------------

%define libnamedev %mklibname %{name} %{api} -d
%define oldwebkitdevel %mklibname qt 4 -d

%package -n     %{libnamedev}
Summary:        Qt Webkit 2.3 Development Files
Group:          Development/KDE and Qt
Requires:       %{libname} = %{version}-%{release}
Requires:       qt4-devel
Provides:       %{name}-devel = %{version}-%{release}
Conflicts:      %{oldwebkitdevel} < 4:4.7.4-6


%description -n %{libnamedev}
Development files to build applications against Qt Webkit 2.3.x

%files -n %{libnamedev}
%{_qt4_datadir}/mkspecs/modules/qt_webkit.pri
%{_qt4_includedir}/QtWebKit/
%{_qt4_libdir}/libQtWebKit.prl
%{_qt4_libdir}/libQtWebKit.so
%{_qt4_libdir}/pkgconfig/QtWebKit.pc

#------------------------------------------------------------------------------

%prep
%setup -q -c
%autopatch -p1

%build 
PATH="%{_qt4_bindir}:$PATH"; export PATH
QTDIR=%{_qt4_prefix}; export QTDIR

Tools/Scripts/build-webkit \
  --qt \
  --release \
  --3d-rendering \
  --qmakearg="CONFIG+=production_build DEFINES+=HAVE_LIBWEBP=1 QMAKE_CFLAGS=\"%optflags\" QMAKE_CXXFLAGS=\"%optflags\" QMAKE_LFLAGS=\"%{?ldflags}\" QMAKE_STRIP=" \
  --makeargs="%{_smp_mflags}" \
%ifarch %{ix86}
  --no-force-sse2
%endif
  
%install
%makeinstall -C WebKitBuild/Release INSTALL_ROOT=%{buildroot}

# Remove rpath
chrpath --list   %{buildroot}%{_qt4_libdir}/libQtWebKit.so.4.10.? ||:
chrpath --delete %{buildroot}%{_qt4_libdir}/libQtWebKit.so.4.10.? ||:

## pkgconfig love
# drop Libs.private, it contains buildroot references, and
# we don't support static linking libQtWebKit anyway
pushd %{buildroot}%{_libdir}/pkgconfig
grep -v "^Libs.private:" QtWebKit.pc > QtWebKit.pc.new && \
mv QtWebKit.pc.new QtWebKit.pc
popd


%changelog
* Wed Mar 15 2017 mrambo3501 <mrambo3501> 2.3.4-9.mga6
+ Revision: 1092800
- Rebuild for icu-58.2

* Fri May 20 2016 eatdirt <eatdirt> 2.3.4-8.mga6
+ Revision: 1017199
- Rebuild with bootstrapped qt-mobility (test)

* Thu Mar 17 2016 daviddavid <daviddavid> 2.3.4-7.mga6
+ Revision: 992332
- rediff unappliable g++-5.0-build patch (since fixed autopatch)

* Sat Jan 02 2016 luigiwalser <luigiwalser> 2.3.4-6.mga6
+ Revision: 918206
- rebuild for libwebp

* Sun Oct 25 2015 blino <blino> 2.3.4-5.mga6
+ Revision: 895260
- pass distro CFLAGS/CXXFLAGS/LFAGS to qmake, like qmake_qt4 macro
  (this also fixes JIT build on armv5tl, since it passes -march=armv5tl,
  while gcc defaults to armv4tl because of a patch)

* Fri Oct 23 2015 blino <blino> 2.3.4-4.mga6
+ Revision: 894343
- disable strip by explicitely passing empty QMAKE_STRIP= since we are not using qmake_qt4 macro
- Fix g++ 5.0 build (backport from upstream qt5-qtwebkit, QTBUG-44829)
- remove phonon buildrequires (code removed since 2.2)

* Wed Apr 22 2015 luigiwalser <luigiwalser> 2.3.4-3.mga5
+ Revision: 820552
- add patch from fedora to fix security issue (mga#15749, rhbz#1204795)

* Fri Feb 06 2015 lmenut <lmenut> 2.3.4-2.mga5
+ Revision: 813728
- build against GStreamer 1.0

* Wed Oct 15 2014 umeabot <umeabot> 2.3.4-1.mga5
+ Revision: 747322
- Second Mageia 5 Mass Rebuild

* Wed Oct 01 2014 lmenut <lmenut> 2.3.4-0.mga5
+ Revision: 734464
- update to 2.3.4

* Tue Sep 16 2014 umeabot <umeabot> 2.3.3-5.mga5
+ Revision: 688565
- Mageia 5 Mass Rebuild

* Sat Feb 15 2014 luigiwalser <luigiwalser> 2.3.3-4.mga5
+ Revision: 592110
- rebuild for libwebp

* Mon Dec 23 2013 neoclust <neoclust> 2.3.3-3.mga4
+ Revision: 560260
- Add a provide for qtwebkit, needed by Google Music s music manager ( mga #7943)

* Tue Oct 22 2013 umeabot <umeabot> 2.3.3-2.mga4
+ Revision: 545235
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 luigiwalser <luigiwalser> 2.3.3-1.mga4
+ Revision: 500923
- 2.3.3
- partial sync with fedora
- update some incorrect references to qtwebkit 2.2 to say 2.3

* Sun Aug 04 2013 lmenut <lmenut> 2.3.2-2.mga4
+ Revision: 463341
- bump release to be higher than in mga3 update

* Sat Jul 13 2013 mikala <mikala> 2.3.2-1.mga4
+ Revision: 453888
- Update tarball to 2.3.2

* Sun Jun 02 2013 fwang <fwang> 2.3.0-3.mga4
+ Revision: 434677
- rebuild for new libpng

* Mon May 27 2013 neoclust <neoclust> 2.3.0-2.mga4
+ Revision: 428732
- Do not add qt5 buildrequires
  Fix crashes on non sse2 machines

* Mon May 27 2013 blino <blino> 2.3.0-1.mga4
+ Revision: 428722
- buildrequire qt5widgets-private-devel for private/qaccessiblewidget_p.h

* Mon Mar 25 2013 neoclust <neoclust> 2.3.0-1.mga3
+ Revision: 405217
- New version 2.3.0

* Sun Jan 13 2013 umeabot <umeabot> 2.2.2-5.mga3
+ Revision: 380065
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Sep 08 2012 fwang <fwang> 2.2.2-4.mga3
+ Revision: 290279
- force qt4 flavour

* Sat Sep 08 2012 fwang <fwang> 2.2.2-3.mga3
+ Revision: 290267
- fix build with gcc 4.7
- replace patch with upstream r124099
- force to bond with qt4

  + neoclust <neoclust>
    - Fix build with new bison
    - Make sure to not build against Qt5

* Thu May 31 2012 mikala <mikala> 2.2.2-1.mga3
+ Revision: 252095
- Update tarball to QtWebkit 2.2.2

* Sun Apr 08 2012 mikala <mikala> 2.2.1-4.mga2
+ Revision: 229674
- Update tarball to sync standalone version with the version shipped in Qt 4.8.1
- Remove old tarball
- Rediff patch301

* Wed Jan 25 2012 mikala <mikala> 2.2.1-3.mga2
+ Revision: 200681
- Rebuild for Qt4.8 (new qtprefix)

* Mon Dec 26 2011 dmorgan <dmorgan> 2.2.1-2.mga2
+ Revision: 187963
- Rebuild against new qt4 and new include path

* Sat Dec 24 2011 mikala <mikala> 2.2.1-1.mga2
+ Revision: 187242
- Update tarball to 2.2.1

* Sun Dec 18 2011 mikala <mikala> 2.2.0-2.mga2
+ Revision: 184040
- Fix libification (split out the qml plugin is in own package)

* Sun Dec 11 2011 mikala <mikala> 2.2.0-1.mga2
+ Revision: 180488
- Enable qt-mobility-devel as BR
- Add patchs from fedora :
 - patch300 to fix build with glib 2.31
 - patch301 to fix build with gcc 4.6
- sync spec with fedora's one (use of chrpath)
- Remove wrong epoch
- Update to qtwebkit2.2
- remove epoch
- use api 2.2 to for library & devel package name
- conflicts against the qtwebkit package from qt package without version
- remove %%defattr()
- use pkgconfig() for BR
- br sqlite3 & not sqlite
- remove useless BR
- drop patch100
- remove useless provides added on a package which is not build at all
- enable  3d-canvas & 3d-rendering
- remove macro definition since there's already provided by qt4-devel

  + ze <ze>
    - imported package qtwebkit


* Mon Aug 08 2011 Zé <ze@mandriva.org> 2.2-0.git20110808.1.mde2
- move to tag qtwebkit-2.2-week31 (SHA 66b76cd)
- change versioning to a fix date (theres a tag shedule)

* Sat Aug 06 2011 Zé <ze@mandriva.org> 2.2-0.git20110806.1.mde2
- sync git repo (revision 4e1a62f..6c2f6bb)

* Tue Jul 26 2011 Zé <ze@mageia.org> 2.2-0.git2011726.1.mde2
- move to branch 2.2 (SHA 4e1a62f)
- update patches

* Fri Jul 22 2011 Zé <ze@mageia.org> 2.1-0.git2011722.1.mde2
- first package
- from branch 2.1 (revision 0f2aaa0..4e1a62f)
